MsgConvResult class

The result of error message conversion, used in IUtil.formatMessageEx.

Constructors

MsgConvResult(String message, bool messageValid, Uint8List messageBytes)

Properties

hashCode int
The hash code for this object.
no setterinherited
message String
getter/setter pair
messageBytes Uint8List
getter/setter pair
messageValid bool
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited