FbOptions class

Database connection options.

Objects of class FbOptions can be passed to FbDb.attach and FbDb.createDatabase to set some additional properties of the attachment or the database that is about to be created.

Example:

final db = await FbDb.createDatabase(
  host: "localhost",
  database: "testdb",
  // set the page size of the new database to 8kB
  // and the default database character set to UTF8
  options: FbOptions(pageSize: 8192, dbCharset: "UTF8"),
);
// work with the database here using the db attachment object
await db.detach();
// db cannot be used any more

See FbDb Programmer's Guide for details.

Constructors

FbOptions({Set<FbTrFlag> transactionFlags = defaultTransactionFlags, int? lockTimeout, int pageSize = 4096, String dbCharset = "UTF8", String? dbCollation, String? libFbClient})
Constructs a new options object with reasonable defaults.

Properties

dbCharset String
The default database character set for new databases.
getter/setter pair
dbCollation String?
The default collation for new databases.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
libFbClient String?
The location of the fbclient native dynamic library.
getter/setter pair
lockTimeout int?
The timeout for resolving lock conflicts with wait transactions.
getter/setter pair
pageSize int
The page size for new databases (relevant only when calling FbDb.createDatabase).
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
transactionFlags Set<FbTrFlag>
Default flags for new transactions.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
transactionFlagsDefault() bool
Checks if the current transaction flags are the same as default ones.

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

defaultTransactionFlags → const Set<FbTrFlag>
Default transaction flags.